# Create or re-create the pleiades database tables and indexes.

# Only needed for initial creation:
# create database pleiades character set utf8 collate utf8_general_ci;
# grant select on pleiades.* to ''@'%.ed.ac.uk';
# Or: "grant select on pleiades.* to ''@'%';" for access from outside network.

use pleiades;

--
-- Table structure for table `location`
--

DROP TABLE IF EXISTS `location`;
CREATE TABLE `location` (
  `authors` varchar(56) DEFAULT NULL,
  `avgRating` varchar(10) DEFAULT NULL,
  `bbox` varchar(22) DEFAULT NULL,
  `created` varchar(20) DEFAULT NULL,
  `creators` varchar(10) DEFAULT NULL,
  `currentVersion` varchar(10) DEFAULT NULL,
  `description` varchar(10) DEFAULT NULL,
  `featureTypes` varchar(7) DEFAULT NULL,
  `geometry` varchar(108) DEFAULT NULL,
  `id` varchar(15) DEFAULT NULL,
  `locationPrecision` varchar(5) DEFAULT NULL,
  `maxDate` decimal(4,1) DEFAULT NULL,
  `minDate` decimal(5,1) DEFAULT NULL,
  `modified` varchar(20) DEFAULT NULL,
  `numRatings` varchar(10) DEFAULT NULL,
  `path` varchar(30) DEFAULT NULL,
  `pid` int(6) DEFAULT NULL,
  `reprLat` decimal(3,1) DEFAULT NULL,
  `reprLatLong` varchar(19) DEFAULT NULL,
  `reprLong` decimal(3,1) DEFAULT NULL,
  `tags` varchar(10) DEFAULT NULL,
  `timePeriods` varchar(5) DEFAULT NULL,
  `timePeriodsKeys` varchar(59) DEFAULT NULL,
  `timePeriodsRange` varchar(12) DEFAULT NULL,
  `title` varchar(25) DEFAULT NULL,
  `uid` varchar(32) DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Location and geometry of Pleiades places';

--
-- Table structure for table `name`
--

DROP TABLE IF EXISTS `name`;
CREATE TABLE `name` (
  `authors` varchar(67) DEFAULT NULL,
  `avgRating` varchar(10) DEFAULT NULL,
  `bbox` varchar(42) DEFAULT NULL,
  `created` varchar(20) DEFAULT NULL,
  `creators` varchar(10) DEFAULT NULL,
  `currentVersion` varchar(10) DEFAULT NULL,
  `description` varchar(10) DEFAULT NULL,
  `extent` varchar(108) DEFAULT NULL,
  `id` varchar(14) DEFAULT NULL,
  `locationPrecision` varchar(9) DEFAULT NULL,
  `maxDate` decimal(4,1) DEFAULT NULL,
  `minDate` decimal(5,1) DEFAULT NULL,
  `modified` varchar(20) DEFAULT NULL,
  `nameAttested` varchar(10) DEFAULT NULL,
  `nameLanguage` varchar(2) DEFAULT NULL,
  `nameTransliterated` varchar(14) DEFAULT NULL,
  `numRatings` varchar(10) DEFAULT NULL,
  `path` varchar(29) DEFAULT NULL,
  `pid` int(6) DEFAULT NULL,
  `reprLat` varchar(8) DEFAULT NULL,
  `reprLatLong` varchar(19) DEFAULT NULL,
  `reprLong` varchar(8) DEFAULT NULL,
  `tags` varchar(10) DEFAULT NULL,
  `timePeriods` varchar(4) DEFAULT NULL,
  `timePeriodsKeys` varchar(51) DEFAULT NULL,
  `timePeriodsRange` varchar(12) DEFAULT NULL,
  `title` varchar(14) DEFAULT NULL,
  `uid` varchar(32) DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Attested and transliterated names for Pleiades places';

--
-- Table structure for table `place`
--

DROP TABLE IF EXISTS `place`;
CREATE TABLE `place` (
  `authors` varchar(74) DEFAULT NULL,
  `bbox` varchar(42) DEFAULT NULL,
  `connectsWith` varchar(6) DEFAULT NULL,
  `created` varchar(20) DEFAULT NULL,
  `creators` varchar(10) DEFAULT NULL,
  `currentVersion` int(2) DEFAULT NULL,
  `description` varchar(73) DEFAULT NULL,
  `extent` varchar(108) DEFAULT NULL,
  `featureTypes` varchar(10) DEFAULT NULL,
  `geoContext` varchar(55) DEFAULT NULL,
  `hasConnectionsWith` varchar(33) DEFAULT NULL,
  `id` int(6) DEFAULT NULL,
  `locationPrecision` varchar(7) DEFAULT NULL,
  `maxDate` decimal(5,1) DEFAULT NULL,
  `minDate` decimal(5,1) DEFAULT NULL,
  `modified` varchar(20) DEFAULT NULL,
  `path` varchar(14) DEFAULT NULL,
  `reprLat` decimal(8,6) DEFAULT NULL,
  `reprLatLong` varchar(19) DEFAULT NULL,
  `reprLong` decimal(8,6) DEFAULT NULL,
  `tags` varchar(59) DEFAULT NULL,
  `timePeriods` varchar(6) DEFAULT NULL,
  `timePeriodsKeys` varchar(66) DEFAULT NULL,
  `timePeriodsRange` varchar(13) DEFAULT NULL,
  `title` varchar(22) DEFAULT NULL,
  `uid` varchar(32) DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Main Pleiades table, of places with id info';

--
-- Table structure for table `plplus`
--

DROP TABLE IF EXISTS `plplus`;
CREATE TABLE `plplus` (
  `pleiades_url` varchar(38) DEFAULT NULL,
  `geonames_url` varchar(32) DEFAULT NULL,
  `match_type` varchar(4) DEFAULT NULL,
  `distance` int(1) DEFAULT NULL,
  `pleiades_locationPrecision` varchar(5) DEFAULT NULL,
  `pleiades_featureTypes` varchar(8) DEFAULT NULL,
  `geonames_featurecode` varchar(5) DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


# Create indexes

create index plurlInd on plplus(pleiades_url);
create index pathInd on place(path);
create index titleInd on place(title);
create index nametInd on name(nameTransliterated);
create index nameaInd on name(nameAttested);
